@@ -159,7 +159,7 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.2.30'
+__version__ = '0.2.31'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -431,12 +431,11 @@ class Tooltip(ScrollView):
     def __init__(self, **kwargs):
         self.main_app = App.get_running_app().main_app
         self.targeted_widget = self.main_app.help_activator     # set default-value before calling super()
+        # init binder before super().__init__ because calls back on_targeted_widget if targeted_widget is in kwargs
+        self._targeted_binder = AbsolutePosSizeBinder(self.targeted_widget)
 
         super().__init__(**kwargs)
 
-        self._targeted_binder = AbsolutePosSizeBinder(self.targeted_widget)
-        self._actual_pos()                                      # init self.anchor_spe
-
     def _actual_pos(self, *_args) -> Tuple[float, float]:
         wid = self.targeted_widget
         win_w, win_h = Window.size
@@ -472,6 +471,10 @@ class Tooltip(ScrollView):
 
         return min_x <= touch_x < max_x and min_y <= touch_y < max_y
 
+    def on_size(self, *_args):
+        """ (re-)position help_activator tooltip correctly after help text loading and layout resizing. """
+        self.pos = self._actual_pos()
+
     def on_targeted_widget(self, *_args):
         """ targeted widget changed event handler.
 
@@ -883,8 +886,10 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
             ),
             'layout_font_size': (
                 ('@',
-                 "A(value=layout.main_app.framework_app.max_font_size, t='in_out_sine', d=12.9) + "
-                 "A(value=layout.main_app.framework_app.min_font_size, t='in_out_sine', d=4.2)"),
+                 "A(value=min(layout.main_app.font_size * 1.5, layout.main_app.framework_app.max_font_size),"
+                 "  t='in_out_sine', d=12.9) + "
+                 "A(value=max(layout.main_app.font_size * 0.6, layout.main_app.framework_app.min_font_size),"
+                 "  t='in_out_sine', d=4.2)"),
             )
         })
 
